from setuptools import setup

setup(name='dglab2018',
      version='0.1',
      description='Data processing and analysis scripts supporting the PhD project by one Dominik Gotojuch',
      url='https://github.com/robotgentleman/dglab2018',
      author='Dominik Gotojuch',
      author_email='dominik@gotojuch.com',
      license='MIT',
      packages=['dglab2018'],
      zip_safe=False)